@@ -1,9 +1,13 @@
 """Pathlib implementation that uses our own glob."""
+from __future__ import annotations
+import ntpath
+import posixpath
 import pathlib
 import os
 from . import glob
 from . import _wcparse
 from . import util
+from typing import Iterable, Any, Sequence
 
 __all__ = (
     "CASE", "IGNORECASE", "RAWCHARS", "DOTGLOB", "DOTMATCH",
@@ -68,67 +72,22 @@ FLAG_MASK = (
 )
 
 
-class Path(pathlib.Path):
-    """Special pathlike object (which accesses the filesystem) that uses our own glob methods."""
-
-    __slots__ = ()
-
-    def __new__(cls, *args, **kwargs):
-        """New."""
-
-        if cls is Path:
-            cls = WindowsPath if os.name == 'nt' else PosixPath
-        if util.PY310:
-            self = cls._from_parts(args)
-        else:
-            self = cls._from_parts(args, init=False)
-        if not self._flavour.is_supported:
-            raise NotImplementedError("Cannot instantiate {!r} on your system".format(cls.__name__))
-        if not util.PY310:
-            self._init()
-        return self
-
-    def glob(self, patterns, *, flags=0, limit=_wcparse.PATTERN_LIMIT):
-        """
-        Search the file system.
-
-        `GLOBSTAR` is enabled by default in order match the default behavior of `pathlib`.
-
-        """
-
-        if self.is_dir():
-            scandotdir = flags & SCANDOTDIR
-            flags = self._translate_flags(flags | _NOABSOLUTE) | ((_PATHLIB | SCANDOTDIR) if scandotdir else _PATHLIB)
-            for filename in glob.iglob(patterns, flags=flags, root_dir=str(self), limit=limit):
-                yield self.joinpath(filename)
-
-    def rglob(self, patterns, *, flags=0, limit=_wcparse.PATTERN_LIMIT):
-        """
-        Recursive glob.
-
-        This uses the same recursive logic that the default `pathlib` object uses.
-        Folders and files are essentially matched from right to left.
-
-        `GLOBSTAR` is enabled by default in order match the default behavior of `pathlib`.
-
-        """
-
-        yield from self.glob(patterns, flags=flags | _EXTMATCHBASE, limit=limit)
-
-
 class PurePath(pathlib.PurePath):
     """Special pure pathlike object that uses our own glob methods."""
 
     __slots__ = ()
 
-    def __new__(cls, *args):
+    def __new__(cls, *args: str) -> 'PurePath':
         """New."""
 
         if cls is PurePath:
             cls = PureWindowsPath if os.name == 'nt' else PurePosixPath
-        return cls._from_parts(args)
+        if not util.PY312:
+            return cls._from_parts(args)  # type: ignore[no-any-return,attr-defined]
+        else:
+            return object.__new__(cls)
 
-    def _translate_flags(self, flags):
+    def _translate_flags(self, flags: int) -> int:
         """Translate flags for the current `pathlib` object."""
 
         flags = (flags & FLAG_MASK) | _PATHNAME
@@ -144,7 +103,7 @@ class PurePath(pathlib.PurePath):
             flags |= _FORCEUNIX
         return flags
 
-    def _translate_path(self):
+    def _translate_path(self) -> str:
         """Translate the object to a path string and ensure trailing slash for non-pure paths that are directories."""
 
         sep = ''
@@ -154,7 +113,14 @@ class PurePath(pathlib.PurePath):
 
         return name + sep
 
-    def match(self, patterns, *, flags=0, limit=_wcparse.PATTERN_LIMIT):
+    def match(  # type: ignore[override, unused-ignore]
+        self,
+        patterns: str | Sequence[str],
+        *,
+        flags: int = 0,
+        limit: int = _wcparse.PATTERN_LIMIT,
+        exclude: str | Sequence[str] | None = None
+    ) -> bool:
         """
         Match patterns using `globmatch`, but also using the same right to left logic that the default `pathlib` uses.
 
@@ -165,9 +131,16 @@ class PurePath(pathlib.PurePath):
 
         """
 
-        return self.globmatch(patterns, flags=flags | _RTL, limit=limit)
+        return self.globmatch(patterns, flags=flags | _RTL, limit=limit, exclude=exclude)
 
-    def globmatch(self, patterns, *, flags=0, limit=_wcparse.PATTERN_LIMIT):
+    def globmatch(
+        self,
+        patterns: str | Sequence[str],
+        *,
+        flags: int = 0,
+        limit: int = _wcparse.PATTERN_LIMIT,
+        exclude: str | Sequence[str] | None = None
+    ) -> bool:
         """
         Match patterns using `globmatch`, but without the right to left logic that the default `pathlib` uses.
 
@@ -179,21 +152,92 @@ class PurePath(pathlib.PurePath):
             self._translate_path(),
             patterns,
             flags=self._translate_flags(flags),
-            limit=limit
+            limit=limit,
+            exclude=exclude
         )
 
 
+class Path(pathlib.Path):
+    """Special pathlike object (which accesses the filesystem) that uses our own glob methods."""
+
+    __slots__ = ()
+
+    def __new__(cls, *args: str, **kwargs: Any) -> 'Path':
+        """New."""
+
+        win_host = os.name == 'nt'
+        if cls is Path:
+            cls = WindowsPath if win_host else PosixPath
+        if not util.PY312:
+            if util.PY310:
+                self = cls._from_parts(args)  # type: ignore[attr-defined]
+            else:
+                self = cls._from_parts(args, init=False)  # type: ignore[attr-defined]
+            if not self._flavour.is_supported:
+                raise NotImplementedError("Cannot instantiate {!r} on your system".format(cls.__name__))
+            if not util.PY310:
+                self._init()
+            return self  # type: ignore[no-any-return]
+        else:
+            if cls is WindowsPath and not win_host or cls is not WindowsPath and win_host:
+                raise NotImplementedError("Cannot instantiate {!r} on your system".format(cls.__name__))
+            return object.__new__(cls)
+
+    def glob(  # type: ignore[override]
+        self,
+        patterns: str | Sequence[str],
+        *,
+        flags: int = 0,
+        limit: int = _wcparse.PATTERN_LIMIT,
+        exclude: str | Sequence[str] | None = None
+    ) -> Iterable['Path']:
+        """
+        Search the file system.
+
+        `GLOBSTAR` is enabled by default in order match the default behavior of `pathlib`.
+
+        """
+
+        if self.is_dir():
+            scandotdir = flags & SCANDOTDIR
+            flags = self._translate_flags(  # type: ignore[attr-defined]
+                flags | _NOABSOLUTE
+            ) | ((_PATHLIB | SCANDOTDIR) if scandotdir else _PATHLIB)
+            for filename in glob.iglob(patterns, flags=flags, root_dir=str(self), limit=limit, exclude=exclude):
+                yield self.joinpath(filename)
+
+    def rglob(  # type: ignore[override]
+        self,
+        patterns: str | Sequence[str],
+        *,
+        flags: int = 0,
+        limit: int = _wcparse.PATTERN_LIMIT,
+        exclude: str | Sequence[str] | None = None
+    ) -> Iterable['Path']:
+        """
+        Recursive glob.
+
+        This uses the same recursive logic that the default `pathlib` object uses.
+        Folders and files are essentially matched from right to left.
+
+        `GLOBSTAR` is enabled by default in order match the default behavior of `pathlib`.
+
+        """
+
+        yield from self.glob(patterns, flags=flags | _EXTMATCHBASE, limit=limit, exclude=exclude)
+
+
 class PurePosixPath(PurePath):
     """Pure Posix path."""
 
-    _flavour = pathlib._posix_flavour
+    _flavour = pathlib._posix_flavour if not util.PY312 else posixpath  # type: ignore[attr-defined]
     __slots__ = ()
 
 
 class PureWindowsPath(PurePath):
     """Pure Windows path."""
 
-    _flavour = pathlib._windows_flavour
+    _flavour = pathlib._windows_flavour if not util.PY312 else ntpath  # type: ignore[attr-defined]
     __slots__ = ()
 
 
